==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Dashboard.pm <==
package WebGUI::i18n::Dutch::Asset_Dashboard;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => 1152624242,
    'message' => 'Dashboard'
  },
  'assets to hide' => {
    'lastUpdated' => 1152623451,
    'message' => 'Te verbergen assets'
  },
  'assets to hide description' => {
    'lastUpdated' => 1152623534,
    'message' => 'Deze lijst bevat een vak voor elk type asset van de pagina layout dat aangevinkt kan worden. Vink dit vak aan bij elke asset die niet getoond moet worden in de pagina layout asset. '
  },
  'dashboard adminsGroupId description' => {
    'lastUpdated' => 1152861173,
    'message' => 'Welke groep mag het dashboard wijzigen? Dit houdt in het wijzigen/verwijderen/toevoegen van beschikbare dashlets, instellingen en sjablonen '
  },
  'dashboard adminsGroupId field label' => {
    'lastUpdated' => 1152861653,
    'message' => 'Wie kan beheren?'
  },
  'dashboard template description' => {
    'lastUpdated' => 1152861641,
    'message' => 'Kies een Dashboard sjabloon. Standaard wordt het sjabloon met drie kolommen gebruikt. '
  },
  'dashboard template field label' => {
    'lastUpdated' => 1152861678,
    'message' => 'Dashboard sjabloon'
  },
  'dashboard usersGroupId description' => {
    'lastUpdated' => 1155554079,
    'message' => 'De groep met gebruikers die hun eigen persoonlijke instellingen en voorkeuren op de site kunnen opslaan. Wanneer iemand in de &quot;Wie kan bekijken?&quot; groep zit maar niet in deze groep, kunnen deze personen de rangschikking van de dashlets persoonlijk instellen (deze plaatsing wordt opgeslagen in cookies), maar zij kunnen niet de eigenschappen van een dashlet bewerken.'
  },
  'dashboard usersGroupId field label' => {
    'lastUpdated' => 1152862184,
    'message' => 'Wie kan personaliseren?'
  },
  'hide new content list' => {
    'lastUpdated' => 1231700981,
    'message' => 'Lijst met verborgen nieuwe inhoud'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Dashboard.pm <==
package WebGUI::i18n::Dutch::Asset_Dashboard;
use utf8;
our $I18N = {
  'Add New Content' => {
    'lastUpdated' => '1302278135',
    'message' => 'Inhoud toevoegen'
  },
  'Is required' => {
    'lastUpdated' => '1302278392',
    'message' => 'Vereist?'
  },
  'Is static' => {
    'lastUpdated' => '1302278379',
    'message' => 'Statisch?'
  },
  'assetName' => {
    'lastUpdated' => '1152624242',
    'message' => 'Dashboard'
  },
  'assets to hide' => {
    'lastUpdated' => '1152623451',
    'message' => 'Te verbergen assets'
  },
  'assets to hide description' => {
    'lastUpdated' => '1152623534',
    'message' => 'Deze lijst bevat een vak voor elk type asset van de pagina layout dat aangevinkt kan worden. Vink dit vak aan bij elke asset die niet getoond moet worden in de pagina layout asset. '
  },
  'dashboard adminsGroupId description' => {
    'lastUpdated' => '1152861173',
    'message' => 'Welke groep mag het dashboard wijzigen? Dit houdt in het wijzigen/verwijderen/toevoegen van beschikbare dashlets, instellingen en sjablonen '
  },
  'dashboard adminsGroupId field label' => {
    'lastUpdated' => '1152861653',
    'message' => 'Wie kan beheren?'
  },
  'dashboard template description' => {
    'lastUpdated' => '1152861641',
    'message' => 'Kies een Dashboard sjabloon. Standaard wordt het sjabloon met drie kolommen gebruikt. '
  },
  'dashboard template field label' => {
    'lastUpdated' => '1152861678',
    'message' => 'Dashboard sjabloon'
  },
  'dashboard usersGroupId description' => {
    'lastUpdated' => '1155554079',
    'message' => 'De groep met gebruikers die hun eigen persoonlijke instellingen en voorkeuren op de site kunnen opslaan. Wanneer iemand in de &quot;Wie kan bekijken?&quot; groep zit maar niet in deze groep, kunnen deze personen de rangschikking van de dashlets persoonlijk instellen (deze plaatsing wordt opgeslagen in cookies), maar zij kunnen niet de eigenschappen van een dashlet bewerken.'
  },
  'dashboard usersGroupId field label' => {
    'lastUpdated' => '1152862184',
    'message' => 'Wie kan personaliseren?'
  },
  'hide new content list' => {
    'lastUpdated' => '1231700981',
    'message' => 'Lijst met verborgen nieuwe inhoud'
  },
  'templateId' => {
    'lastUpdated' => '1302278172',
    'message' => 'Het GUID van het sjabloon waarmee het dashboard wordt weergegeven.'
  }
}
;

1;
